#!/bin/bash


#  slackbuild script for jpilot
# Author: Mark Tucker
# Created: 15 Oct 2006
# Changes:
#        15 Oct 2006 - initial creation

#
#----------------------------------------------------------------------
umask 0022

#----------------------------------------
# include the common functions
#----------------------------------------
if [ -r ./sbuild.functions ]; then
    . ./sbuild.functions
else
    echo Cannot read file `pwd`/sbuild.functions
    echo Exiting....
    echo
    exit
fi

#----------------------------------------
# Set locations for temp directories
#----------------------------------------
# location of source code archive
srcdir=`pwd`/SRC
workdir=`pwd`


#----------------------------------------
# Package variables
#----------------------------------------
source="jpilot-0.99.9.tar.gz"
pkgname="jpilot"
pkgver="0.99.9"
release="1mht"
package="$pkgname-$pkgver-i486-$release.tgz"
realname="Mark Tucker"
echo Package: $package

#----------------------------------------
# setup path variables
#----------------------------------------
set_workdir

# unpack the source
echo Unpacking the source...
tar -xzf $srcdir/$source


cd $builddir

#----------------------------------------
# setup the build environment
#----------------------------------------
export CFLAGS="-O2 -march=i486 -mcpu=i686"
export CPPFLAGS="-O2 -march=i486 -mcpu=i686"
export CXXFLAGS=$CPPFLAGS


#----------------------------------------
# Build the package and install
#----------------------------------------
# configure 
conf_opts="--prefix=/usr \
    --sysconfdir=/etc \
    --localstatedir=/var"

run_configure $conf_opts

# make
run_make

# Set target directory
set_target

# install
run_makeinstall


echo finishing install...


# create install dir
mkdir $target/install

#----------------------------------------
# create slack-desc file to install
#----------------------------------------
cat > $target/install/slack-desc << END
        |-----handy-ruler------------------------------------------------------|
$pkgname: $pkgname $pkgver 
$pkgname:
$pkgname: J-Pilot is a desktop organizer application for PalmOS devices. It 
$pkgname: is meant to be an alternative to the Palm Desktop for those who 
$pkgname: run the most popular Operating Systems in the World, Linux and Unix.
$pkgname: 
$pkgname:
$pkgname: http://www.jpilot.org
$pkgname: 
$pkgname: 
$pkgname: Packaged by Mark Tucker for $slackver
END


# create documentation directory
create_docdir

# fix group on bin directories.
fix_bingrp

# strip  bin files
strip_bin

# strip lib files
strip_libs

# check for uncompressed man pages
compr_man

# makepkg
create_pkg

exit

